@@ -39,12 +39,15 @@
 #' \code{\link{get_capacity}}, \code{\link{get_queue_size}},
 #' \code{\link{get_server_count}}, \code{\link{get_queue_count}},
 #' \code{\link{get_capacity_selected}}, \code{\link{get_queue_size_selected}},
-#' \code{\link{get_server_count_selected}}, \code{\link{get_queue_count_selected}}
+#' \code{\link{get_server_count_selected}}, \code{\link{get_queue_count_selected}},
+#' \code{\link{get_selected}}
 #'
 #' \item Sources: \code{\link{add_generator}}, \code{\link{add_dataframe}},
 #' \code{\link{get_sources}}, \code{\link{get_n_generated}},
 #' \code{\link{get_trajectory}}
 #'
+#' \item Globals: \code{\link{add_global}}, \code{\link{get_global}}.
+#'
 #' \item Data retrieval: \code{\link{get_mon_arrivals}},
 #' \code{\link{get_mon_attributes}}, \code{\link{get_mon_resources}}
 #'
@@ -161,8 +164,10 @@ peek.simmer <- function(.env, steps=1, verbose=FALSE) .env$peek(steps, verbose)
 #'
 #' @inheritParams reset
 #' @param name the name of the resource.
-#' @param capacity the capacity of the server.
-#' @param queue_size the size of the queue.
+#' @param capacity the capacity of the server, either a numeric or a
+#' \code{\link{schedule}}, so that the value may change during the simulation.
+#' @param queue_size the size of the queue, either a numeric or a
+#' \code{\link{schedule}}, so that the value may change during the simulation.
 #' @param mon whether the simulator must monitor this resource or not.
 #' @param preemptive whether arrivals in the server can be preempted or not based
 #' on seize priorities.
@@ -283,6 +288,23 @@ add_dataframe.simmer <- function(.env, name_prefix, trajectory, data, mon=1, bat
   .env$add_dataframe(name_prefix, trajectory, data, mon, batch, col_time, time,
                      col_attributes, col_priority, col_preemptible, col_restart)
 
+#' Add a Global Attribute
+#'
+#' Attach a global variable to the simulation.
+#'
+#' @inheritParams reset
+#' @param key the attribute name.
+#' @param value the value to set, either a numeric or a \code{\link{schedule}},
+#' so that the global may change during the simulation.
+#'
+#' @return Returns the simulation environment.
+#' @seealso Convenience functions: \code{\link{schedule}}.
+#' @export
+add_global <- function(.env, key, value) UseMethod("add_global")
+
+#' @export
+add_global.simmer <- function(.env, key, value) .env$add_global(key, value)
+
 #' Monitoring Statistics
 #'
 #' Getters for obtaining monitored data (if any) about arrivals, attributes and resources.
@@ -346,11 +368,11 @@ get_resources.simmer <- function(.env) names(.env$get_resources())
 #' arrival or a global one, and prioritization values.
 #'
 #' @inheritParams reset
-#' @param source the name of the source.
+#' @param sources one or more resource names.
 #'
-#' @details \code{get_n_generated} returns the number of arrivals generated by a
-#' given source. \code{get_trajectory} returns the trajectory to which it is
-#' attached.
+#' @details \code{get_n_generated} returns the number of arrivals generated by
+#' the given sources. \code{get_trajectory} returns the trajectory to which they
+#' are attached (as a list).
 #'
 #' \code{get_name} returns the number of the running arrival. \code{get_attribute}
 #' returns a running arrival's attributes. If a provided key was not previously
@@ -364,17 +386,17 @@ get_resources.simmer <- function(.env) names(.env$get_resources())
 #' \code{\link{set_attribute}}, \code{\link{set_global}},
 #' \code{\link{set_prioritization}}.
 #' @export
-get_n_generated <- function(.env, source) UseMethod("get_n_generated")
+get_n_generated <- function(.env, sources) UseMethod("get_n_generated")
 
 #' @export
-get_n_generated.simmer <- function(.env, source) .env$get_n_generated(source)
+get_n_generated.simmer <- function(.env, sources) .env$get_n_generated(sources)
 
 #' @rdname get_n_generated
 #' @export
-get_trajectory <- function(.env, source) UseMethod("get_trajectory")
+get_trajectory <- function(.env, sources) UseMethod("get_trajectory")
 
 #' @export
-get_trajectory.simmer <- function(.env, source) .env$get_trajectory(source)
+get_trajectory.simmer <- function(.env, sources) .env$get_trajectory(sources)
 
 #' @rdname get_n_generated
 #' @export
@@ -388,16 +410,10 @@ get_name.simmer <- function(.env) .env$get_name()
 #'
 #' @rdname get_n_generated
 #' @export
-get_attribute <- function(.env, keys, global=FALSE) {
-  if (global) {
-    .Deprecated("get_global", old="get_attribute(global=TRUE)")
-    get_global(.env, keys)
-  }
-  else UseMethod("get_attribute")
-}
+get_attribute <- function(.env, keys) UseMethod("get_attribute")
 
 #' @export
-get_attribute.simmer <- function(.env, keys, global=FALSE) .env$get_attribute(keys)
+get_attribute.simmer <- function(.env, keys) .env$get_attribute(keys)
 
 #' @rdname get_n_generated
 #' @export
@@ -418,63 +434,72 @@ get_prioritization.simmer <- function(.env) .env$get_prioritization()
 #' Getters for resources: server capacity/count and queue size/count.
 #'
 #' @inheritParams reset
-#' @inheritParams select
-#' @param resource the name of the resource.
+#' @param resources one or more resource names.
+#' @param id selection identifier (a negative number causes the function to
+#' return the required parameter for all the selected resources).
 #'
-#' @return Return a numeric value.
+#' @return Return a vector (character for \code{get_selected}, numeric for the
+#' rest of them).
 #' @seealso \code{\link{get_resources}}, \code{\link{set_capacity}},
 #' \code{\link{set_queue_size}}.
 #' @export
-get_capacity <- function(.env, resource) UseMethod("get_capacity")
+get_capacity <- function(.env, resources) UseMethod("get_capacity")
 
 #' @export
-get_capacity.simmer <- function(.env, resource) .env$get_capacity(resource)
+get_capacity.simmer <- function(.env, resources) .env$get_capacity(resources)
 
 #' @rdname get_capacity
 #' @export
 get_capacity_selected <- function(.env, id=0) UseMethod("get_capacity_selected")
 
 #' @export
-get_capacity_selected.simmer <- function(.env, id=0) .env$get_capacity(NA, id)
+get_capacity_selected.simmer <- function(.env, id=0) .env$get_capacity(NULL, id)
 
 #' @rdname get_capacity
 #' @export
-get_queue_size <- function(.env, resource) UseMethod("get_queue_size")
+get_queue_size <- function(.env, resources) UseMethod("get_queue_size")
 
 #' @export
-get_queue_size.simmer <- function(.env, resource) .env$get_queue_size(resource)
+get_queue_size.simmer <- function(.env, resources) .env$get_queue_size(resources)
 
 #' @rdname get_capacity
 #' @export
 get_queue_size_selected <- function(.env, id=0) UseMethod("get_queue_size_selected")
 
 #' @export
-get_queue_size_selected.simmer <- function(.env, id=0) .env$get_queue_size(NA, id)
+get_queue_size_selected.simmer <- function(.env, id=0) .env$get_queue_size(NULL, id)
 
 #' @rdname get_capacity
 #' @export
-get_server_count <- function(.env, resource) UseMethod("get_server_count")
+get_server_count <- function(.env, resources) UseMethod("get_server_count")
 
 #' @export
-get_server_count.simmer <- function(.env, resource) .env$get_server_count(resource)
+get_server_count.simmer <- function(.env, resources) .env$get_server_count(resources)
 
 #' @rdname get_capacity
 #' @export
 get_server_count_selected <- function(.env, id=0) UseMethod("get_server_count_selected")
 
 #' @export
-get_server_count_selected.simmer <- function(.env, id=0) .env$get_server_count(NA, id)
+get_server_count_selected.simmer <- function(.env, id=0) .env$get_server_count(NULL, id)
 
 #' @rdname get_capacity
 #' @export
-get_queue_count <- function(.env, resource) UseMethod("get_queue_count")
+get_queue_count <- function(.env, resources) UseMethod("get_queue_count")
 
 #' @export
-get_queue_count.simmer <- function(.env, resource) .env$get_queue_count(resource)
+get_queue_count.simmer <- function(.env, resources) .env$get_queue_count(resources)
 
 #' @rdname get_capacity
 #' @export
 get_queue_count_selected <- function(.env, id=0) UseMethod("get_queue_count_selected")
 
 #' @export
-get_queue_count_selected.simmer <- function(.env, id=0) .env$get_queue_count(NA, id)
+get_queue_count_selected.simmer <- function(.env, id=0) .env$get_queue_count(NULL, id)
+
+#' @rdname get_capacity
+#' @export
+get_selected <- function(.env, id=0) UseMethod("get_selected")
+
+#' @export
+get_selected.simmer <- function(.env, id=0) .env$get_selected(id)
