@@ -1,3 +1,20 @@
+# Copyright (C) 2017-2018 Iñaki Ucar
+#
+# This file is part of simmer.
+#
+# simmer is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# simmer is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with simmer. If not, see <http://www.gnu.org/licenses/>.
+
 context("utils")
 
 func <- function() {
@@ -6,7 +23,7 @@ func <- function() {
   C <- "asdf"
   D <- -2.1
   E <- function() 1
-  F <- trajectory() %>% timeout(1)
+  F <- trajectory()
   G <- schedule(c(1, 2), c(1, 1), 3)
   H <- c("asdf", "asdf")
   I <- c(1, Inf)
@@ -91,6 +108,15 @@ test_that("argument matching work as expected", {
   expect_error(check_args(var="flag"))
 })
 
+test_that("is_* checkers are searched in the simmer namespace only", {
+  arg_list <- list(1) # not defined
+  arg_numeric <- 1    # defined
+  assign("is_list", function(x) FALSE, pos=.GlobalEnv)
+  assign("is_numeric", function(x) FALSE, pos=.GlobalEnv)
+  on.exit(rm("is_list", "is_numeric", pos=.GlobalEnv))
+  expect_silent(check_args(arg_list = "list", arg_numeric = "numeric"))
+})
+
 test_that("envs_apply works", {
   env <- new.env()
   env$func <- function(x, y) data.frame(x=x, y=y)
